==> allure-0.11.0.0-306-x86_64.pkg.tar.zst: usr/share/haskell/register/allure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Allure
version:              0.11.0.0
visibility:           public
id:                   Allure-0.11.0.0-HyyvuRgS4TD1eFuiHBHH4S
key:                  Allure-0.11.0.0-HyyvuRgS4TD1eFuiHBHH4S
license:              AGPL-3.0-or-later
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Andres Loeh, Mikolaj Konarski and others
homepage:             http://allureofthestars.com
synopsis:             Near-future Sci-Fi roguelike and tactical squad combat game
description:
    Allure of the Stars is a near-future Sci-Fi roguelike
    and tactical squad combat game. Binaries and the game manual
    are available at the homepage. You can also try the game out
    in the browser at <http://allureofthestars.com/play>.

    Not a single image in this game. You have to imagine everything
    yourself, like with a book (a grown-up book, without pictures).
    Once you learn to imagine things, though, you can keep exploring
    and mastering the world and making up stories for a long time.

    The game is written in Haskell using the LambdaHack roguelike
    game engine <http://hackage.haskell.org/package/LambdaHack>.
    Please see the changelog file for recent improvements
    and the issue tracker for short-term plans. Long term goals
    are high replayability and auto-balancing through procedural
    content generation and persistent content modification
    based on player behaviour. Contributions are welcome.

    This is a workaround .cabal file, flattened to eliminate
    internal libraries until generating haddocks for them
    is fixed. The original .cabal file is in .cabal.bkp file.

category:             Game
abi:                  df58ea6f5769e1f4eaa4e83c95fbe259
exposed:              True
exposed-modules:
    Client.UI.Content.Input Client.UI.Content.Screen Content.CaveKind
    Content.FactionKind Content.ItemKind Content.ItemKindActor
    Content.ItemKindBlast Content.ItemKindEmbed Content.ItemKindOrgan
    Content.ItemKindTemporary Content.ModeKind Content.PlaceKind
    Content.RuleKind Content.TileKind
    Implementation.MonadClientImplementation
    Implementation.MonadServerImplementation TieKnot

hidden-modules:       Paths_Allure
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/allure
hs-libraries:         HSAllure-0.11.0.0-HyyvuRgS4TD1eFuiHBHH4S
depends:
    LambdaHack-0.11.0.1-3w0YGRhRa8M8JI5daX18DW
    async-2.2.5-A7cw4gHfrNnBMjsgvHD8kq base-4.18.2.1
    enummapset-0.7.3.0-6KEwJIpaxfj5pmuSvEuE24
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-compact-0.1.0.0 hsini-0.5.2.2-3EhLtZ8yA5475lIGRp693w
    optparse-applicative-0.18.1.0-3S7fKkQk1IxEovxwORLzkN
    primitive-0.9.1.0-LZUymL07sjCJKODqCvDEyu
    splitmix-0.1.3-1R8UAplJQu1iOyuAxImFt template-haskell-2.20.0.0
    text-2.0.2 th-lift-instances-0.1.20-BWEBc5HUJU1CZKJfxZySjS
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/allure/html/Allure.haddock
haddock-html:         /usr/share/doc/allure/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> allure-0.11.0.0-307-x86_64.pkg.tar.zst: usr/share/haskell/register/allure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Allure
version:              0.11.0.0
visibility:           public
id:                   Allure-0.11.0.0-KIY0j8VW9Mg8l2EOQgJvo0
key:                  Allure-0.11.0.0-KIY0j8VW9Mg8l2EOQgJvo0
license:              AGPL-3.0-or-later
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Andres Loeh, Mikolaj Konarski and others
homepage:             http://allureofthestars.com
synopsis:             Near-future Sci-Fi roguelike and tactical squad combat game
description:
    Allure of the Stars is a near-future Sci-Fi roguelike
    and tactical squad combat game. Binaries and the game manual
    are available at the homepage. You can also try the game out
    in the browser at <http://allureofthestars.com/play>.

    Not a single image in this game. You have to imagine everything
    yourself, like with a book (a grown-up book, without pictures).
    Once you learn to imagine things, though, you can keep exploring
    and mastering the world and making up stories for a long time.

    The game is written in Haskell using the LambdaHack roguelike
    game engine <http://hackage.haskell.org/package/LambdaHack>.
    Please see the changelog file for recent improvements
    and the issue tracker for short-term plans. Long term goals
    are high replayability and auto-balancing through procedural
    content generation and persistent content modification
    based on player behaviour. Contributions are welcome.

    This is a workaround .cabal file, flattened to eliminate
    internal libraries until generating haddocks for them
    is fixed. The original .cabal file is in .cabal.bkp file.

category:             Game
abi:                  aa72270d4c658725ba91a3cea774ece6
exposed:              True
exposed-modules:
    Client.UI.Content.Input Client.UI.Content.Screen Content.CaveKind
    Content.FactionKind Content.ItemKind Content.ItemKindActor
    Content.ItemKindBlast Content.ItemKindEmbed Content.ItemKindOrgan
    Content.ItemKindTemporary Content.ModeKind Content.PlaceKind
    Content.RuleKind Content.TileKind
    Implementation.MonadClientImplementation
    Implementation.MonadServerImplementation TieKnot

hidden-modules:       Paths_Allure
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/allure
hs-libraries:         HSAllure-0.11.0.0-KIY0j8VW9Mg8l2EOQgJvo0
depends:
    LambdaHack-0.11.0.1-BBy90WcRHNC9mk1fOy50Sf
    async-2.2.5-Dr6zhmAeBY8Cjr8itA5Fpz base-4.18.2.1
    enummapset-0.7.3.0-BLs9bgvD9eN4Q1bqIzw1Lx
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-compact-0.1.0.0 hsini-0.5.2.2-FVzWMy65J524nch2HQRmlS
    optparse-applicative-0.18.1.0-LPpsyWWBTB8DZOwBIqw3J0
    primitive-0.9.1.0-6uX3awsflEb6ebVZsasp0o
    splitmix-0.1.3-6ATqMcqXAWsFILop4kMW8H template-haskell-2.20.0.0
    text-2.0.2 th-lift-instances-0.1.20-9vxKZwmnoda24dn6m63lzz
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/allure/html/Allure.haddock
haddock-html:         /usr/share/doc/allure/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
